@@ -367,7 +367,9 @@ class BaseEnvironnement(BaseEstimator):
                     data[key] = value.to(control.device)
         with autocast(enabled=control.mixed_type_gpu):
             output = self.forward(**data)
-            target = check_tensor(data[control.target_field])
+            if control.target_checktensor:
+                target = check_tensor(data[control.target_field])
+            else: target = data[control.target_field]
             loss_ = loss_fn(output, target, **loss_kargs)
         if control.gradient_accumulation > 1:
             loss_ /= control.gradient_accumulation
@@ -419,7 +421,9 @@ class BaseEnvironnement(BaseEstimator):
                     data[key] = value.to(control.device)
         with torch.no_grad():
             output = self.forward(**data)
-            target = check_tensor(data[control.target_field])
+            if control.target_checktensor:
+                target = check_tensor(data[control.target_field])
+            else: target = data[control.target_field]
             loss = loss_fn(output, target, **loss_kargs)
         loss = loss.detach()
         self._divergence(loss)
@@ -507,6 +511,7 @@ class BaseEnvironnement(BaseEstimator):
         *,
         eval_dataset: Optional[DataLoader]=None,
         target_field: str='target',
+        target_checktensor: bool=True,
         loss_fn: _Loss,
         loss_kargs: Dict[str, Any]=dict(),
         optimizer: Optional[Optimizer]=None,
@@ -545,6 +550,9 @@ class BaseEnvironnement(BaseEstimator):
             Nom du champ contenu dans X de la target. Par défaut "target". 
             Attention l'implémentation de la foction collate_fn, peut faire 
             changer le nom de la target.
+        target_checktensor: bool (=True)
+            Permet de checker si le champs target est un tensor, sinon le
+            converti. Si False ne checke pas si le champs est un tensor.
         loss_fn : _Loss
             Fonction coût à minimiser (utiliser les fonctions présentes dans 
             torch.nn.functional). Si la fonction est une fonction custom, elle 
